@@ -218,9 +218,10 @@ class Rhel(Fedora):
     
 # Source: http://en.wikipedia.org/wiki/Mac_OS_X#Versions
 _osx_codename_map = {4: 'tiger',
-                     5:  'leopard',
+                     5: 'leopard',
                      6: 'snow',
-                     7: 'lion'}
+                     7: 'lion',
+                     8: 'mountain lion'}
 def _osx_codename(major, minor):
     if major != 10 or minor not in _osx_codename_map:
         raise OsNotDetected("unrecognized version: %s.%s"%(major, minor))
@@ -462,7 +463,7 @@ OsDetect.register_default(OS_DEBIAN, LsbDetect("Debian"))
 OsDetect.register_default(OS_FEDORA, Fedora())
 OsDetect.register_default(OS_FREEBSD, FreeBSD())
 OsDetect.register_default(OS_GENTOO, Gentoo())
-OsDetect.register_default(OS_MINT, LsbDetect("Mint"))
+OsDetect.register_default(OS_MINT, LsbDetect("LinuxMint"))
 OsDetect.register_default(OS_OPENSUSE, OpenSuse())
 OsDetect.register_default(OS_OSX, OSX())
 OsDetect.register_default(OS_RHEL, Rhel())
